diff --git a/MeshLib/Properties-impl.h b/MeshLib/Properties-impl.h
index 8b7669dd7c249769e3f27f873e5168ddac0791b4..6b105c70367521cc83c3a3d7b36af5fab0d3e9f6 100644
--- a/MeshLib/Properties-impl.h
+++ b/MeshLib/Properties-impl.h
@@ -89,7 +89,7 @@ bool Properties::existsPropertyVector(std::string const& name) const
 
 template <typename T>
 bool Properties::existsPropertyVector(std::string const& name,
-                                      MeshItemType const item_type,
+                                      MeshItemType const mesh_item_type,
                                       int const number_of_components) const
 {
     auto const it = _properties.find(name);
@@ -103,7 +103,7 @@ bool Properties::existsPropertyVector(std::string const& name,
     {
         return false;
     }
-    if (property->getMeshItemType() != item_type)
+    if (property->getMeshItemType() != mesh_item_type)
     {
         return false;
     }
diff --git a/MeshLib/Properties.h b/MeshLib/Properties.h
index 1dcf650bbdaa0aa8bb1dc9e3cf1944b9c564629e..638a4b2b4b63b2c3ecde7943411dd8183c368937 100644
--- a/MeshLib/Properties.h
+++ b/MeshLib/Properties.h
@@ -85,12 +85,11 @@ public:
     template <typename T>
     bool existsPropertyVector(std::string const& name) const;
 
     /// Checks if a property vector with given type \c T, \c name, \c item_type
     /// and \c number_of_components exists.
     /// @param name name of the requested property vector
     template <typename T>
-    bool existsPropertyVector(std::string const& name,
-                              MeshItemType const item_type,
+    bool existsPropertyVector(std::string const& property_name,
+                              MeshItemType const mesh_item_type,
                               int const number_of_components) const;
 
     /// Returns a property vector with given \c name or aborts calling OGS_FATAL
@@ -85,12 +85,11 @@ public:
     bool existsPropertyVector(std::string const& name) const;
 
-    /// Checks if a property vector with given type \c T, \c name, \c item_type
-    /// and \c number_of_components exists.
-    /// @param name name of the requested property vector
+    /// Checks if a property vector with given type \c T, \c name, \c
+    /// mesh_item_type, and \c number_of_components exists.
     template <typename T>